/***************************************************************************
 *   Copyright (C) 2008 by Tamino Dauth                                    *
 *   tamino.dauth@web.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QSize>
#include <QFileDialog>
#include <QPrintDialog>
#include <QTranslator>
#include <QPrinter>
#include <QSound>
#include <QActionGroup>

#include "ui_mainwindow.h"

namespace hpp
{

class ProgressDialog;
class LicenceDialog;

class MainWindow : public QMainWindow, public Ui::MainWindow
{
	Q_OBJECT

	public:
		MainWindow();
		~MainWindow();

	private slots:
		void saveAs();
		void print();
		void music();
		void translation();
		void switchLanguage(QAction* action);
		void aboutHpp();
		void aboutQt();
		void run();
		void clear();
		void showLicence();

	private:
		void closeEvent(QCloseEvent *event);
		void createLanguageMenuActions();
		QString getResultsLabel();
		void writeSettings();
		void readSettings();

		int results;
		bool fileWasSaved;
		QFileDialog *fileDialog;
		QPrintDialog *printDialog;
		ProgressDialog *progressDialog;
		LicenceDialog *licenceDialog;

		QTranslator appTranslator;
		QTranslator qtTranslator;
		QString qmPath;
		QSound *backgroundMusic;
		QPrinter printer;

		QActionGroup *languageActionGroup;
		QString language;
};

};

#endif
